.. _sample-selector:

SampleSelector
==============

.. inheritance-diagram:: gmmvi.optimization.gmmvi_modules.sample_selector.SampleSelector gmmvi.optimization.gmmvi_modules.sample_selector.VipsSampleSelector gmmvi.optimization.gmmvi_modules.sample_selector.LinSampleSelector
    :parts: -4

.. autoclass:: gmmvi.optimization.gmmvi_modules.sample_selector.SampleSelector
   :members:

.. _lin-selection:

LinSampleSelector
~~~~~~~~~~~~~~~~~
.. autoclass:: gmmvi.optimization.gmmvi_modules.sample_selector.LinSampleSelector
   :members:

.. _vips-selection:

VipsSampleSelector
~~~~~~~~~~~~~~~~~~
.. autoclass:: gmmvi.optimization.gmmvi_modules.sample_selector.VipsSampleSelector
   :members:

.. toctree::
   :maxdepth: 2
   :glob: